[PROJECT_TITLE]

Server is offline, waiting ...
The browser can't read local files. Enable it to continue. I.e. use --allow-file-access-from-files on Chrome

### Kicad Revision Inspector

#### [SCH_TITLE]

Rev. [SCH_REVISION] ([SCH_DATE])

#### [PCB_TITLE]

Rev. [PCB_REVISION] ([PCB_DATE])

Commits

Newer ([COMMIT_1_HASH])
Older ([COMMIT_2_HASH])
Unchanged

Pages

Layers

#### Shortcuts

##### Commits List

`⇧` | Move commits par upwards
`⇩` | Move commits par downwards
`[` or `Ctrl+⇧` | Move 2nd commit upwards
`]` or `Ctrl+⇩` | Move 2nd commit downwards
`r` | Reset commit selection to the top 2 commits

##### View, sheets and layers

`s` | Switch Schematic/Layout view
`q` | Toggle visibility of newer commit
`w` | Toggle visibility of older commit
`⇨` | Select next page/layer
`⇦` | Select previous page/layer
`Ctrl + ⇨` | Select next page/layer (cycling)
`Ctrl + ⇦` | Select previous page/layer (cycling)

##### Diff Pan and Zoom

`+` | Zoom in
`-` | Zoom out
`0` | Zoom fit
`Alt + ⇧` | Pan svg up
`Alt + ⇩` | Pan svg down
`Alt + ⇨` | Pan svg left
`Alt + ⇦` | Pan svg right

##### Miscellaneous

`f` | Toggle full screen view
`i` | Shows this info view